@@ -1169,6 +1169,11 @@ def read_log(name, scalar_only=False):
         msg = 'gsd module is not available'
         raise RuntimeError(msg)
 
+    min_supported_numpy = 2
+    if int(numpy.version.version.split('.')[0]) < min_supported_numpy:
+        msg = 'read_log requires numpy >= 2.0'
+        raise RuntimeError(msg)
+
     with gsd.fl.open(
         name=str(name),
         mode='r',
@@ -1195,12 +1200,17 @@ def read_log(name, scalar_only=False):
                     tmp = numpy.array([0], dtype=numpy.uint64)
                 else:
                     tmp = gsdfileobj.read_chunk(frame=0, name=log)
+                    # if chunk contains string, put it in the numpy array
+                    if isinstance(tmp, str):
+                        tmp = numpy.array([tmp], dtype=numpy.dtypes.StringDType)
 
                 if scalar_only and not tmp.shape[0] == 1:
                     continue
                 if tmp.shape[0] == 1:
                     logged_data_dict[log] = numpy.full(
-                        fill_value=tmp[0], shape=(gsdfileobj.nframes,)
+                        fill_value=tmp[0],
+                        shape=(gsdfileobj.nframes,),
+                        dtype=tmp.dtype,
                     )
                 else:
                     logged_data_dict[log] = numpy.tile(
@@ -1212,7 +1222,12 @@ def read_log(name, scalar_only=False):
                     if not gsdfileobj.chunk_exists(frame=idx, name=key):
                         continue
                     data = gsdfileobj.read_chunk(frame=idx, name=key)
-                    if len(logged_data_dict[key][idx].shape) == 0:
+                    if (
+                        not isinstance(
+                            logged_data_dict[key].dtype, numpy.dtypes.StringDType
+                        )
+                        and len(logged_data_dict[key][idx].shape) == 0
+                    ):
                         logged_data_dict[key][idx] = data[0]
                     else:
                         logged_data_dict[key][idx] = data
