@@ -36,7 +36,7 @@ from collections import namedtuple
 
 import numpy
 
-version = '3.3.0'
+version = '3.4.2'
 
 logger = logging.getLogger('gsd.pygsd')
 
@@ -53,16 +53,17 @@ gsd_index_entry = namedtuple('gsd_index_entry', 'frame N location M id type flag
 gsd_index_entry_struct = struct.Struct('QQqIHBB')
 
 gsd_type_mapping = {
-    1: numpy.dtype('uint8'),
-    2: numpy.dtype('uint16'),
-    3: numpy.dtype('uint32'),
-    4: numpy.dtype('uint64'),
-    5: numpy.dtype('int8'),
-    6: numpy.dtype('int16'),
-    7: numpy.dtype('int32'),
-    8: numpy.dtype('int64'),
-    9: numpy.dtype('float32'),
-    10: numpy.dtype('float64'),
+    1: ('uint8', numpy.dtype('uint8')),
+    2: ('uint16', numpy.dtype('uint16')),
+    3: ('uint32', numpy.dtype('uint32')),
+    4: ('uint64', numpy.dtype('uint64')),
+    5: ('int8', numpy.dtype('int8')),
+    6: ('int16', numpy.dtype('int16')),
+    7: ('int32', numpy.dtype('int32')),
+    8: ('int64', numpy.dtype('int64')),
+    9: ('float32', numpy.dtype('float32')),
+    10: ('float64', numpy.dtype('float64')),
+    11: ('str', numpy.dtype('int8')),
 }
 
 
@@ -333,7 +334,7 @@ class GSDFile:
             'read chunk: ' + str(self.__file) + ' - ' + str(frame) + ' - ' + name
         )
 
-        size = chunk.N * chunk.M * gsd_type_mapping[chunk.type].itemsize
+        size = chunk.N * chunk.M * gsd_type_mapping[chunk.type][1].itemsize
         if chunk.location == 0:
             raise RuntimeError(
                 'Corrupt chunk: '
@@ -345,7 +346,7 @@ class GSDFile:
             )
 
         if size == 0:
-            return numpy.array([], dtype=gsd_type_mapping[chunk.type])
+            return numpy.array([], dtype=gsd_type_mapping[chunk.type][1])
 
         self.__file.seek(chunk.location, 0)
         data_raw = self.__file.read(size)
@@ -353,7 +354,11 @@ class GSDFile:
         if len(data_raw) != size:
             raise OSError
 
-        data_npy = numpy.frombuffer(data_raw, dtype=gsd_type_mapping[chunk.type])
+        # If gsd type is character, decode it here
+        if gsd_type_mapping[chunk.type][0] == 'str':
+            data_npy = data_raw.decode('utf-8')
+        else:
+            data_npy = numpy.frombuffer(data_raw, dtype=gsd_type_mapping[chunk.type][1])
 
         if chunk.M == 1:
             return data_npy
