@@ -1,4 +1,4 @@
-# Copyright (c) 2016-2023 The Regents of the University of Michigan
+# Copyright (c) 2016-2024 The Regents of the University of Michigan
 # Part of GSD, released under the BSD 2-Clause License.
 
 """Command line options for pytest."""
@@ -12,25 +12,26 @@ def pytest_addoption(parser):
     * validate - run validation tests
     """
     parser.addoption(
-        "--validate",
-        action="store_true",
+        '--validate',
+        action='store_true',
         default=False,
-        help="Enable long running validation tests.",
+        help='Enable long running validation tests.',
     )
 
 
 @pytest.fixture(autouse=True)
-def skip_validate(request):
+def _skip_validate(request):
     """Skip validation tests by default.
 
     Pass the command line option --validate to enable these tests.
     """
     if request.node.get_closest_marker('validate'):
-        if not request.config.getoption("validate"):
+        if not request.config.getoption('validate'):
             pytest.skip('Validation tests not requested.')
 
 
 def pytest_configure(config):
     """Define the ``validate`` marker."""
     config.addinivalue_line(
-        "markers", "validate: Tests that perform long-running validations.")
+        'markers', 'validate: Tests that perform long-running validations.'
+    )
