@@ -1,30 +1,32 @@
-# Copyright (c) 2016-2023 The Regents of the University of Michigan
+# Copyright (c) 2016-2024 The Regents of the University of Michigan
 # Part of GSD, released under the BSD 2-Clause License.
 
 """Benchmark GSD HOOMD file read/write."""
 
-import time
-import gsd.fl
-import gsd.pygsd
-import gsd.hoomd
-import os
 import math
+import os
 import random
-import numpy
 import sys
-from subprocess import call, PIPE
+import time
+from subprocess import PIPE, call
+
+import numpy
+
+import gsd.fl
+import gsd.hoomd
+import gsd.pygsd
 
 # import logging
 # logging.basicConfig(level=logging.DEBUG)
 
 
-def write_frame(file, frame, position, orientation):
+def write_frame(file, frame_idx, position, orientation):
     """Write a frame to the file."""
     frame = gsd.hoomd.Frame()
     frame.particles.N = position.shape[0]
-    frame.configuration.step = frame * 10
-    position[0][0] = frame
-    orientation[0][0] = frame
+    frame.configuration.step = frame_idx * 10
+    position[0][0] = frame_idx
+    orientation[0][0] = frame_idx
     frame.particles.position = position
     frame.particles.orientation = orientation
     file.append(frame)
@@ -44,7 +46,7 @@ def write_file(file, nframes, N, position, orientation):
 
     for i in range(0, nframes):
         if i % step == 0:
-            print(i, "/", nframes, file=sys.stderr, flush=True)
+            print(i, '/', nframes, file=sys.stderr, flush=True)
 
         write_frame(file, i, position, orientation)
 
@@ -58,7 +60,7 @@ def read_sequential_file(file, nframes, nframes_read, N, position, orientation):
 
     for i in range(0, nframes_read):
         if i % step == 0:
-            print(i, "/", nframes, file=sys.stderr, flush=True)
+            print(i, '/', nframes, file=sys.stderr, flush=True)
 
         read_frame(file, i, position, orientation)
 
@@ -75,7 +77,7 @@ def read_random_file(file, nframes, nframes_read, N, position, orientation):
 
     for i, f in enumerate(frames[:nframes_read]):
         if i % step == 0:
-            print(i, "/", nframes, file=sys.stderr, flush=True)
+            print(i, '/', nframes, file=sys.stderr, flush=True)
         read_frame(file, f, position, orientation)
 
 
@@ -99,8 +101,9 @@ def run_benchmarks(N, size):
     bmark_read_size = 0.25 * 1024**3
 
     timings = {}
-    position = numpy.random.random((N, 3)).astype('float32')
-    orientation = numpy.random.random((N, 4)).astype('float32')
+    rng = numpy.random.default_rng()
+    position = rng.random((N, 3)).astype('float32')
+    orientation = rng.random((N, 4)).astype('float32')
 
     nframes = compute_nframes(N, size)
     actual_size = compute_actual_size(N, nframes)
@@ -111,7 +114,7 @@ def run_benchmarks(N, size):
         bmark_read_size = actual_size
 
     # first, write the file and time how long it takes
-    print("Writing file: ", file=sys.stderr, flush=True)
+    print('Writing file: ', file=sys.stderr, flush=True)
 
     # if the file size is small, write it once to warm up the disk
     if size < 64 * 1024**3:
@@ -132,20 +135,19 @@ def run_benchmarks(N, size):
     timings['write'] = actual_size / 1024**2 / (end - start)
 
     # time how long it takes to open the file
-    print("Opening file... ", file=sys.stderr, flush=True, end='')
+    print('Opening file... ', file=sys.stderr, flush=True, end='')
     start = time.time()
     with gsd.hoomd.open(name='test.gsd', mode='r') as hf:
         end = time.time()
 
-        print(end - start, "s", file=sys.stderr, flush=True)
+        print(end - start, 's', file=sys.stderr, flush=True)
 
-        timings['open_time'] = (end - start)
+        timings['open_time'] = end - start
 
         # Read the file sequentially and measure the time taken
-        print("Sequential read file:", file=sys.stderr, flush=True)
+        print('Sequential read file:', file=sys.stderr, flush=True)
         start = time.time()
-        read_sequential_file(hf, nframes, nframes_read, N, position,
-                             orientation)
+        read_sequential_file(hf, nframes, nframes_read, N, position, orientation)
         end = time.time()
 
         timings['seq_read'] = bmark_read_size / 1024**2 / (end - start)
@@ -155,7 +157,7 @@ def run_benchmarks(N, size):
         call(['sudo', '/sbin/sysctl', 'vm.drop_caches=3'], stdout=PIPE)
 
         # Read the file randomly and measure the time taken
-        print("Random read file:", file=sys.stderr, flush=True)
+        print('Random read file:', file=sys.stderr, flush=True)
         start = time.time()
         read_random_file(hf, nframes, nframes_read, N, position, orientation)
         end = time.time()
@@ -173,38 +175,59 @@ def run_sweep(size, size_str):
     if True:
         result = run_benchmarks(32 * 32, size)
 
-        print("{0:<7} {1:<6} {2:<9.4g} {3:<12.4g} "
-              "{4:<11.4g} {5:<13.4g} {6:<11.3g}".format(
-                  size_str, "32^2", result['open_time'] * 1000, result['write'],
-                  result['seq_read'], result['random_read'],
-                  result['random_read_time']))
+        print(
+            '{:<7} {:<6} {:<9.4g} {:<12.4g} {:<11.4g} {:<13.4g} {:<11.3g}'.format(
+                size_str,
+                '32^2',
+                result['open_time'] * 1000,
+                result['write'],
+                result['seq_read'],
+                result['random_read'],
+                result['random_read_time'],
+            )
+        )
         sys.stdout.flush()
 
     result = run_benchmarks(128 * 128, size)
 
-    print("{0:<7} {1:<6} {2:<9.4g} {3:<12.4g} {4:<11.4g} {5:<13.4g} {6:<11.3g}"
-          .format(size_str, "128^2", result['open_time'] * 1000,
-                  result['write'], result['seq_read'], result['random_read'],
-                  result['random_read_time']))
+    print(
+        '{:<7} {:<6} {:<9.4g} {:<12.4g} {:<11.4g} {:<13.4g} {:<11.3g}'.format(
+            size_str,
+            '128^2',
+            result['open_time'] * 1000,
+            result['write'],
+            result['seq_read'],
+            result['random_read'],
+            result['random_read_time'],
+        )
+    )
     sys.stdout.flush()
 
     result = run_benchmarks(1024 * 1024, size)
 
-    print("{0:<7} {1:<6} {2:<9.4g} {3:<12.4g} {4:<11.4g} {5:<13.4g} {6:<11.3g}"
-          .format(size_str, "1024^2", result['open_time'] * 1000,
-                  result['write'], result['seq_read'], result['random_read'],
-                  result['random_read_time']))
+    print(
+        '{:<7} {:<6} {:<9.4g} {:<12.4g} {:<11.4g} {:<13.4g} {:<11.3g}'.format(
+            size_str,
+            '1024^2',
+            result['open_time'] * 1000,
+            result['write'],
+            result['seq_read'],
+            result['random_read'],
+            result['random_read_time'],
+        )
+    )
     sys.stdout.flush()
 
 
-print("""
+print(
+    """
 ======= ====== ========= ============ =========== ============= ===========
 Size    N      Open (ms) Write (MB/s) Read (MB/s) Random (MB/s) Random (ms)
-======= ====== ========= ============ =========== ============= ===========""")
+======= ====== ========= ============ =========== ============= ==========="""
+)
 
-run_sweep(128 * 1024**2, "128 MiB")
-run_sweep(1 * 1024**3, "1 GiB")
+run_sweep(128 * 1024**2, '128 MiB')
+run_sweep(1 * 1024**3, '1 GiB')
 # run_sweep(128*1024**3, "128 GiB");
 
-print("======= ====== ========= ============ "
-      "=========== ============= ===========")
+print('======= ====== ========= ============ =========== ============= ===========')
